@@ -64,6 +64,8 @@ typedef enum tagLogLevel_t
 /*---------- PROTOTYPES [API] ----------*/
 LogLevel_t LogLevel(void);
 
+void LogSetFile( FILE* fp );
+
 void LogPrintf (LogLevel_t, const char* format, ...) _LAL_GCC_PRINTF_FORMAT_(2,3);
 void LogPrintfVerbatim (LogLevel_t, const char* format, ...) _LAL_GCC_PRINTF_FORMAT_(2,3);
 
@@ -73,6 +75,7 @@ int XLALfprintfGSLvector_int ( FILE *fp, const char *fmt, const gsl_vector_int *
 
 REAL8 XLALGetTimeOfDay(void);
 REAL8 XLALGetCPUTime ( void );
+const char * LogGetTimestamp (void);
 
 REAL8 XLALGetPeakHeapUsageMB ( void );
 
