@@ -38,16 +38,46 @@ extern "C" {
 
 /*@{*/
 
+///
+/// Convert an unsigned long index \c i into a bit, i.e. \f$b = 2^i\f$
+///
+#define XLAL_IDX2BIT(i) (1UL << ((unsigned long)(i)))
+
+///
+/// Convert an unsigned long \e single bit \c b into an index, i.e. \f$i = \log_2 b \f$
+///
+#define XLAL_BIT2IDX(b) ( \
+    (((((unsigned long)(b)) & 0xAAAAAAAAAAAAAAAAUL) != 0)) | \
+    (((((unsigned long)(b)) & 0xCCCCCCCCCCCCCCCCUL) != 0) << 1UL) | \
+    (((((unsigned long)(b)) & 0xF0F0F0F0F0F0F0F0UL) != 0) << 2UL) | \
+    (((((unsigned long)(b)) & 0xFF00FF00FF00FF00UL) != 0) << 3UL) | \
+    (((((unsigned long)(b)) & 0xFFFF0000FFFF0000UL) != 0) << 4UL) | \
+    (((((unsigned long)(b)) & 0xFFFFFFFF00000000UL) != 0) << 5UL) \
+    )
+
 ///
 /// A range of REAL8 values; first element is minimum, second element is maximum of range
 ///
 typedef REAL8 REAL8Range[2];
 
+///
+/// A range of INT4 values; first element is minimum, second element is maximum of range
+///
+typedef INT4 INT4Range[2];
+
 ///
 /// A range of GPS times; first element is minimum, second element is maximum of range
 ///
 typedef LIGOTimeGPS LIGOTimeGPSRange[2];
 
+///
+/// Possible choices the user may select for an enumeration or bitflag
+///
+#ifdef SWIG /* SWIG interface directives */
+SWIGLAL(IMMUTABLE_MEMBERS(tagUserChoice, name));
+#endif /* SWIG */
+typedef struct tagUserChoice { int val; const char *name; } UserChoices[32];
+
 // ---------- Function prototypes ----------
 int XLALParseStringValueAsINT4PlusFrac ( INT4 *valINT4, REAL8 *valFrac, const char *valString );
 
@@ -64,11 +94,15 @@ int XLALParseStringValueAsEPOCH ( LIGOTimeGPS *gps, const char *valString );
 int XLALParseStringValueAsRAJ ( REAL8 *valRAJ, const char *valString );
 int XLALParseStringValueAsDECJ ( REAL8 *valDECJ, const char *valString );
 
+int XLALParseStringValueAsINT4Range ( INT4Range *int4Range, const char *valString );
 int XLALParseStringValueAsREAL8Range ( REAL8Range *real8Range, const char *valString );
 int XLALParseStringValueAsEPOCHRange ( LIGOTimeGPSRange *gpsRange, const char *valString );
 int XLALParseStringValueAsRAJRange ( REAL8Range *rajRange, const char *valString );
 int XLALParseStringValueAsDECJRange ( REAL8Range *decjRange, const char *valString );
 
+int XLALParseStringValueAsUserEnum ( int *valEnum, const UserChoices *enumData, const char *valString );
+int XLALParseStringValueAsUserFlag ( int *valFlag, const UserChoices *flagData, const char *valString );
+
 int XLALParseStringValueAsSTRING ( CHAR **valOut, const char *valString );
 int XLALParseStringValueAsSTRINGVector ( LALStringVector **valSTRINGVector, const CHAR *valString );
 
