@@ -94,6 +94,13 @@ void XLALHeapDestroy(
   LALHeap *h                    /**< [in] Pointer to heap */
   );
 
+/**
+ * Clear a heap
+ */
+int XLALHeapClear(
+  LALHeap *h                    /**< [in] Pointer to heap */
+  );
+
 /**
  * Return the size of a heap
  */
@@ -108,6 +115,13 @@ int XLALHeapMaxSize(
   const LALHeap *h              /**< [in] Pointer to heap */
   );
 
+/**
+ * Return >0 if a limited-size heap is full, 0 otherwise (or if heap has unlimited size), or <0 on error
+ */
+int XLALHeapIsFull(
+  const LALHeap *h              /**< [in] Pointer to heap */
+  );
+
 /**
  * Return the root element of a heap
  */
