@@ -123,11 +123,6 @@ if ( (func), (statusptr)->statusCode )                               \
 }                                                                    \
 else (void)(0)
 
-/* A global pointer for debugging. */
-#ifndef NDEBUG
-char *lalWatch;
-#endif
-
 int
 main(int argc, char **argv)
 {
