@@ -167,12 +167,6 @@ if ( (func), (statusptr)->statusCode )                               \
 }                                                                    \
 while (0)
 
-/* A global pointer for debugging. */
-#ifndef NDEBUG
-char *lalWatch;
-#endif
-
-
 int
 main( int argc, char **argv )
 {
